﻿using DryIoc.ImTools;
using StudentManager.Data;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace StudentManager.Common
{
	public class HomeWork
	{
		public int Lesson { get; set; } = 0;
		public bool Status { get; set; } = false;
		public HashSet<QuestionBase> Questions { get; set; } = new HashSet<QuestionBase>();

		public void AddHomeWork(QuestionBase workInfo)
		{
			Questions.Add(workInfo);
		}

		public void AddHomeWork(int id)
		{
			Questions.Add(new QuestionBase { ID = id });
		}

		public void RemoveHomeWork(QuestionBase workInfo)
		{
			Questions.Remove(workInfo);
		}

		public void Append(HomeWork homeWork)
		{
			foreach (var item in homeWork.Questions)
			{
				Questions.Add(item);
			}

		}
	}

	public class HomeWorkSet
	{
		private Dictionary<int, HomeWork> HomeWorks { get; set; } = new Dictionary<int, HomeWork>();


		public void AddHomeWork(HomeWork homeWork)
		{
			HomeWorks.Add(homeWork.Lesson, homeWork);
		}


		public void RemoveHomeWork(HomeWork homeWork)
		{
			HomeWorks.Remove(homeWork.Lesson);
		}

		public HomeWork Get(int cursonId)
		{
			return HomeWorks[cursonId];
		}

		public List<HomeWork> GetAll()
		{
			return HomeWorks.Values.ToList();
		}

		public ObservableCollection<HomeWork> GetAllByColl()
		{
			ObservableCollection<HomeWork> works = new ObservableCollection<HomeWork>();

			foreach (var item in HomeWorks)
			{
				works.Add(item.Value);
			}
			return works;
		}

		public void QueryCQSet(int id)
		{
			HomeWorks.Clear();

			SQLHelper.Query<CursonQuestionsData>(Tables.CQTable, id).ForEach(x =>
			{
				HashSet<QuestionBase> Questions = new HashSet<QuestionBase>();
				x.ProblemIDS.ForEach(y => Questions.Add(new QuestionBase { ID = y, Status = x.CorrectIDS.Contains(y) }));
				HomeWorks.Add(x.Lesson, new HomeWork { Lesson = x.Lesson, Questions = Questions, Status = x.Status == 1 });
			});
		}
	}

}
